@@ -1,13 +1,14 @@
 <?php
-/*
 
 // The admin side of our 1.1 update system
 
 function core_update_footer( $msg = '' ) {
+	if( !is_site_admin() )
+		return false;
 	if ( !current_user_can('manage_options') )
 		return sprintf( '| '.__( 'Version %s' ), $GLOBALS['wp_version'] );
 
-	$cur = get_option( 'update_core' );
+	$cur = get_site_option( 'update_core' );
 
 	switch ( $cur->response ) {
 	case 'development' :
@@ -29,13 +30,15 @@ function core_update_footer( $msg = '' ) {
 add_filter( 'update_footer', 'core_update_footer' );
 
 function update_nag() {
-	$cur = get_option( 'update_core' );
+	if( !is_site_admin() )
+		return false;
+	$cur = get_site_option( 'update_core' );
 
 	if ( ! isset( $cur->response ) || $cur->response != 'upgrade' )
 		return false;
 
 	if ( current_user_can('manage_options') )
-		$msg = sprintf( __('WordPress %2$s is available! <a href="%1$s">Please update now</a>.'), $cur->url, $cur->current );
+		$msg = sprintf( __('<strong>Site Administrator</strong>: WordPress %2$s is available! A new version of WordPress MU will be <a href="%1$s">available</a> soon.'), $cur->url, $cur->current );
 	else
 		$msg = sprintf( __('WordPress %2$s is available! Please notify the site administrator.'), $cur->url, $cur->current );
 
@@ -45,7 +48,9 @@ add_action( 'admin_notices', 'update_nag', 3 );
 
 // Called directly from dashboard
 function update_right_now_message() {
-	$cur = get_option( 'update_core' );
+	if( !is_site_admin() )
+		return false;
+	$cur = get_site_option( 'update_core' );
 
 	$msg = sprintf( __('This is WordPress version %s.'), $GLOBALS['wp_version'] );
 	if ( isset( $cur->response ) && $cur->response == 'upgrade' && current_user_can('manage_options') )
@@ -53,7 +58,6 @@ function update_right_now_message() {
 
 	echo "<span id='wp-version-message'>$msg</span>";
 }
-*/
 
 function wp_plugin_update_row( $file, $plugin_data ) {
 	if( !is_site_admin() )
