@@ -61,6 +61,7 @@ switch( $_GET['action'] ) {
 		}
 
 		update_site_option( "menu_items", $_POST['menu_items'] );
+		update_site_option( "mu_media_buttons", $_POST['mu_media_buttons'] );
 		update_site_option( "blog_upload_space", $_POST['blog_upload_space'] );
 		update_site_option( "upload_filetypes", $_POST['upload_filetypes'] );
 		update_site_option( "site_name", $_POST['site_name'] );
@@ -112,6 +113,11 @@ switch( $_GET['action'] ) {
 			$path = $base.$domain.'/';
 		}
 
+		$domain = strtolower( $domain );
+		$newdomain = strtolower( $newdomain );
+		$path = strtolower( $path );
+
+		$password = 'N/A';
 		$user_id = email_exists($email);
 		if( !$user_id ) {
 			$password = generate_random_password();
@@ -131,6 +137,7 @@ switch( $_GET['action'] ) {
 				update_user_option( $user_id, 'primary_blog', $id, true );
 			$content_mail = sprintf( __( "New blog created by %1s\n\nAddress: http://%2s\nName: %3s"), $current_user->user_login , $newdomain.$path, stripslashes( $title ) );
 			wp_mail( get_site_option('admin_email'),  sprintf(__('[%s] New Blog Created'), $current_site->site_name), $content_mail, 'From: "Site Admin" <' . get_site_option( 'admin_email' ) . '>' );
+			wpmu_welcome_notification( $id, $user_id, $password, $title, array( "public" => 1 ) );
 			wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'add-blog'), $_SERVER['HTTP_REFERER'] ) );
 			exit();
 		} else {
