@@ -673,19 +673,12 @@ class RSSCache {
 	Output:		true on sucess
 \*=======================================================================*/
 	function set ($url, $rss) {
-		global $wpdb, $wp_object_cache;
+		global $wpdb;
 		$cache_option = 'rss_' . $this->file_name( $url );
 		$cache_timestamp = 'rss_' . $this->file_name( $url ) . '_ts';
 
-		if( $wp_object_cache->cache_enabled ) {
-			wp_cache_set( $cache_option, $rss, 'rss' );
-			wp_cache_set( $cache_timestamp, $cache_timestamp, 'rss' );
-		} else {
-			if( !get_site_option( $cache_option ) )
-				add_site_option( $cache_option, $rss );
-			if( !get_site_option( $cache_timestamp ) )
-				add_site_option( $cache_timestamp, $cache_timestamp );
-		}
+		add_site_option( $cache_option, $rss );
+		add_site_option( $cache_timestamp, $cache_timestamp );
 
 		return $cache_option;
 	}
@@ -697,23 +690,14 @@ class RSSCache {
 	Output:		cached object on HIT, false on MISS
 \*=======================================================================*/
 	function get ($url) {
-		global $wp_object_cache;
 		$this->ERROR = "";
 		$cache_option = 'rss_' . $this->file_name( $url );
 
-		if( $wp_object_cache->cache_enabled ) {
-			if( ! wp_cache_get( $cache_option, 'rss' ) ) {
-				$this->debug( "Cache doesn't contain: $url (cache option: $cache_option)" );
-				return 0;
-			}
-			return wp_cache_get( $cache_option, 'rss' );
-		} else {
-			if ( ! get_site_option( $cache_option ) ) {
-				$this->debug( "Cache doesn't contain: $url (cache option: $cache_option)" );
-				return 0;
-			}
-			return get_site_option( $cache_option );
+		if ( ! get_site_option( $cache_option ) ) {
+			$this->debug( "Cache doesn't contain: $url (cache option: $cache_option)" );
+			return 0;
 		}
+		return get_site_option( $cache_option );
 	}
 
 /*=======================================================================*\
